@@ -121,6 +121,7 @@ class PlantTracer:
 
     def _get_object_id(self, object: Union[Message, Plan, Assignment, Task, Artifact, Dict[str, Any]]) -> str:
         object_dict = self._convert_to_dict(object)
+        object_class_name = object.__class__.__name__.lower()
         if 'id' in object_dict:
             id = object_dict['id']
         else:
@@ -128,10 +129,14 @@ class PlantTracer:
             if 'kind' in object_dict:
                 kind = object_dict['kind']
             else:
-                kind = object.__class__.__name__.lower()
+                kind = object_class_name
 
             if f"{kind}Id" in object_dict:
                 id = object_dict[f"{kind}Id"]
+            elif "task" in object_class_name and "event" in object_class_name and "taskId" in object_dict:
+                id = object_dict["taskId"]
+            elif "task" in object_class_name and "event" in object_class_name and "task_id" in object_dict:
+                id = object_dict["task_id"]
             else:
                 raise ValueError(f"Missing id in object: {object_dict}, kind: {kind}")
         return id
@@ -157,6 +162,11 @@ class PlantTracer:
 
 
     async def submit_object_produced_consumed(self, new_object, from_objects: Optional[List[str]] = None):
+        if self.auto_link_from_objects:
+            self.produced_objects.append(self._get_object_id(new_object))
+            if from_objects is None:
+                from_objects = self.consumed_objects
+
         return await self.submit_object_tracing_data(new_object, 'produced_consumed', from_objects)
     
 
